@@ -1,7 +1,7 @@
 {-# LANGUAGE OverloadedStrings    #-}
 {-# LANGUAGE LambdaCase           #-}
 {- |
-Copyright               : © 2021-2023 Albert Krewinkel
+Copyright               : © 2021-2025 Albert Krewinkel
 SPDX-License-Identifier : MIT
 Maintainer              : Albert Krewinkel <tarleb+pandoc@moltkeplatz.de>
 
@@ -54,7 +54,7 @@ peekCellFuzzy idx = liftLua (ltype idx) >>= \case
 
 -- | Cell object type.
 typeCell :: LuaError e => DocumentedType e Cell
-typeCell = deftype "pandoc Cell"
+typeCell = deftype "Cell"
   [ operation Eq $ defun "__eq"
      ### liftPure2 (\a b -> fromMaybe False ((==) <$> a <*> b))
      <#> parameter (optional . peekCell) "Cell" "self" ""
@@ -111,9 +111,13 @@ mkCell = defun "Cell"
                   (maybe 1 RowSpan mRowSpan)
                   (maybe 1 ColSpan mColSpan)
                   blocks)
-  <#> parameter peekBlocksFuzzy "Blocks" "blocks" "document contents"
-  <#> opt (parameter peekAlignment "integer" "align" "cell alignment")
-  <#> opt (parameter peekIntegral "integer" "row_span" "rows to span")
-  <#> opt (parameter peekIntegral "integer" "col_span" "columns to span")
+  <#> parameter peekBlocksFuzzy "Blocks" "blocks" "cell contents"
+  <#> opt (parameter peekAlignment "Alignment" "align"
+           "text alignment; defaults to `AlignDefault`")
+  <#> opt (parameter peekIntegral "integer" "rowspan"
+           "number of rows occupied by the cell; defaults to `1`")
+  <#> opt (parameter peekIntegral "integer" "colspan"
+           "number of columns occupied by the cell; defaults to `1`")
   <#> opt (parameter peekAttr "Attr" "attr" "cell attributes")
   =#> functionResult pushCell "Cell" "new Cell object"
+  #? "Create a new table cell."
